/*
 *  Medard for Maemo.
 *  Copyright (C) 2011 Roman Moravcik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#ifdef Q_WS_MAEMO_6
#include <MApplicationPage>
#include <MLabel>
#include <MButton>
#include <MComboBox>
#else
#include <QMainWindow>
#include <QActionGroup>
#include <QLabel>
#include <QPushButton>
#endif

#include "forecastwidget.h"
#include "medarddownloader.h"

#ifdef Q_WS_MAEMO_6
class MainWindow : public MApplicationPage
#else
class MainWindow : public QMainWindow
#endif
{
    Q_OBJECT

public:
#ifdef Q_WS_MAEMO_6
    MainWindow(QGraphicsItem *parent = 0);
#else
    MainWindow(QWidget *parent = 0);
#endif
    virtual ~MainWindow();

private slots:
    void seaLevelPreasureMenuClicked();
    void precipitationMenuClicked();
    void windVelocityMenuClicked();
    void cloudinessMenuClicked();
    void temperatureMenuClicked();
    void aboutMenuClicked();

    void downloadAgainClicked();

    void plusDayClicked();
    void minusDayClicked();
    void plusHourClicked();
    void minusHourClicked();

#if Q_WS_MAEMO_6
    void forecastDomainChanged(int index);
    void forecastTypeChanged(int index);
#else
    void forecastDomainChanged(QAction *action);
#endif

    void downloadedFinished(const QString &filename, const QDateTime &date);
    void downloadFailed();

private:
    void setupUi();
    void setupMenu();
    void loadSettings();

    void showNavigationButtons();
    void hideNavigationButtons(bool showRetryButton);
    void updateNavigationButtons();

    void setForecastType(const QString label, MedardDownloader::ForecastType type);
    void setForecastDateOffset(int offset);

private:
    MedardDownloader *m_downloader;

    ForecastWidget *m_forecast;
#if Q_WS_MAEMO_6
    MLabel *m_forecastTypeLabel;
    MLabel *m_forecastInitialDateLabel;
    MLabel *m_forecastDateLabel;

    MButton *m_downloadRetryButton;

    MButton *m_minusDayButton;
    MButton *m_plusDayButton;
    MButton *m_minusHourButton;
    MButton *m_plusHourButton;

    MComboBox *m_forecastDomainComboBox;
    MComboBox *m_forecastTypeComboBox;
#else
    QLabel *m_forecastTypeLabel;
    QLabel *m_forecastInitialDateLabel;
    QLabel *m_forecastDateLabel;

    QPushButton *m_downloadRetryButton;

    QPushButton *m_minusDayButton;
    QPushButton *m_plusDayButton;
    QPushButton *m_minusHourButton;
    QPushButton *m_plusHourButton;

    QActionGroup *m_domainActionGroup;
#endif

};

#endif // MAINWINDOW_H
